#extension GL_OES_EGL_image_external : require

precision mediump float;

varying vec2 textureCoordinate;
varying vec2 textureBgCoordinate;

//相机的数据的纹理
uniform sampler2D s_texture;
//抠图处理结果的纹理，纹理格式其实四个通道的值是一样的，0代表前景即人脸的部分，1代表背景，0-1代表边缘
uniform sampler2D inputImageTexture1;
//背景的纹理
uniform sampler2D inputImageTexture2;
//描边的颜色
uniform vec4 vOutlineColor;
//脸部分的颜色，当设置的颜色值无效时，抠图区域依然显示相机的数据
uniform vec4 vMaskColor;
//是否使用背景的纹理，如果不用应该显示相机的数据
uniform bool useTexture2;
//是否进行描边
uniform bool hasOutline;
//是否使用颜色填冲抠图区域
uniform bool useMaskColor;

bool isBg(const vec4 maskColor);
bool isEdge(const sampler2D fabbyTexture, const vec2 maskCoord, const float step);

bool isBg(const vec4 maskColor)
{
    return (maskColor.r + maskColor.g + maskColor.b) == 0.0;
}

//inputImageTexture1为fabby的抠图纹理
bool isEdge(const sampler2D fabbyTexture, const vec2 maskCoord, const highp float step){
    highp float a = 0.0;
    for(int i = -1; i < 2; i++){
        for(int j = -1; j < 2; j++){
            float x = maskCoord.x;
            highp vec2 tmp = vec2(maskCoord.x + float(i) * step, maskCoord.y + float(j) * step);
            a += texture2D(fabbyTexture, tmp).a;
        }
    }
    highp float average = a / 9.0;
    return average > 0.5 && average < 0.55;
}

void main() {
    vec2 maskCoord = vec2(textureCoordinate.x, textureCoordinate.y);
    vec2 bgCoord = vec2(textureBgCoordinate.x, textureBgCoordinate.y);

    highp vec4 camColor = texture2D(s_texture, maskCoord);
    highp vec4 maskColor = texture2D(inputImageTexture1, maskCoord);
    highp vec4 bgColor = texture2D(inputImageTexture2, bgCoord);
    if(useMaskColor){
        bgColor = vMaskColor;
    }
    highp vec3 bgMix;
    float a = smoothstep(0.4, 0.8, maskColor.r);
    bgMix = mix(useMaskColor ? bgColor.rgb : camColor.rgb, useMaskColor ? camColor.rgb : bgColor.rgb, 1.0 - a);

    gl_FragColor.rgb = bgMix;
    gl_FragColor.a = 1.0;
    //进行描边
    if(hasOutline){
        float step = 0.01;
        bool isedge = isEdge(inputImageTexture1, maskCoord, step);
        if(isedge){
            gl_FragColor = vOutlineColor;
        }
    }
}

