#extension GL_OES_EGL_image_external : require
precision highp float;
uniform sampler2D inputImageTexture;
uniform sampler2D spotTexture;
uniform sampler2D inputImageTexture1;


varying highp vec2 textureCoordinate;
uniform int extra;
uniform float texelWidth;
uniform float texelHeight;
uniform float ctrlLevel;
uniform int spotValid;

const lowp float pi = 3.14159265;

vec2 transLevelToParam(const float level){
    vec2 ret = vec2(0.0, 0.0);
    if(level < 33.0){
        ret.x = 3.0;
        ret.y = level / 33.0 * 1.5 + 2.0;
    }else if(level >= 33.0 && level <= 66.0){
        ret.x = 3.0;
        ret.y = (level - 33.0)/33.0 * 1.5 + 3.0;
    }else{
        ret.x = 5.0;
        ret.y = (level - 66.0)/33.0 * 2.0 + 3.0;
    }
    return ret;
}


vec4 calculateBlurValue(const float kernel, const float level){
    float sigma = level;
    float numBlurPixelsPerSide = kernel / 2.0;
    int   horizontal = extra;
    vec2  blurMultiplyVec = horizontal > 0 ? vec2(1.0, 0.0) : vec2(0.0, 1.0);
    float offsetx = horizontal > 0 ? float(1.0/texelWidth) : float(0.0);
    float offsety = horizontal > 0 ? float(0.0) : 1.0/texelHeight;
    vec2  singleStepOffset = vec2(offsetx, offsety);

    vec3 incrementalGaussian;
    incrementalGaussian.x = 1.0 / (sqrt(2.0 * pi) * sigma);
    incrementalGaussian.y = exp(-0.5 / (sigma * sigma));
    incrementalGaussian.z = incrementalGaussian.y * incrementalGaussian.y;

    vec4 avgValue = vec4(0.0, 0.0, 0.0, 0.0);
    float coefficientSum = 0.0;

    // Take the central sample first...
    avgValue += texture2D(inputImageTexture, textureCoordinate.st) * incrementalGaussian.x;
    coefficientSum += incrementalGaussian.x;
    incrementalGaussian.xy *= incrementalGaussian.yz;

     // Go through the remaining 8 vertical samples (4 on each side of the center)
    for (float i = 1.0; i <= numBlurPixelsPerSide; i++) {
        avgValue += texture2D(inputImageTexture, textureCoordinate.st - i * singleStepOffset *
                                      blurMultiplyVec) * incrementalGaussian.x;
        avgValue += texture2D(inputImageTexture, textureCoordinate.st + i * singleStepOffset *
                                      blurMultiplyVec) * incrementalGaussian.x;
        coefficientSum += 2.0 * incrementalGaussian.x;
        incrementalGaussian.xy *= incrementalGaussian.yz;
     }
     return  avgValue / coefficientSum;
}

bool isOutline(const sampler2D fabbyTexture, const vec2 maskCoord, const highp float step){
    highp float a = 0.0;
    for(int i = -1; i < 2; i++){
        for(int j = -1; j < 2; j++){
            float x = maskCoord.x;
            highp vec2 tmp = vec2(maskCoord.x + float(i) * step, maskCoord.y + float(j) * step);
            a += texture2D(fabbyTexture, tmp).a;
        }
    }
    highp float average = a / 9.0;
    return average > 0.5 && average < 0.55;
}

void main()
{
    vec2 maskCoord = vec2(textureCoordinate.x, textureCoordinate.y);
    highp vec4 maskColor = texture2D(inputImageTexture1, maskCoord);
    float a = smoothstep(0.1, 0.9, maskColor.r);

    highp vec4 bgColor;
    bool isMask = (maskColor.r + maskColor.g + maskColor.b) >= 1.0;
    bool isEdge = a > 0.0 && a < 1.0;

    if(isEdge){
           vec2 param = transLevelToParam(ctrlLevel);
           bgColor = calculateBlurValue(param.x, (1.0 - maskColor.r)*param.y);
//           highp vec4 camColor = texture2D(inputImageTexture, textureCoordinate);
//           bgColor = camColor;
       }else{
         if(isMask){
               highp vec4 camColor = texture2D(inputImageTexture, textureCoordinate);
               bgColor = camColor;
           }else{
                bool fixSpot = false;
//                if(spotValid > 0){
//                     highp vec4 spotColor = texture2D(spotTexture, textureCoordinate);
//                     bool isSpot = (spotColor.r != 0.0 && spotColor.a != 0.0);
//                     if(isSpot){
//                          vec2 param = transLevelToParam(100.0);
//                          bgColor = calculateBlurValue(param.x, param.y);
//                          fixSpot = true;
//                    }
//                }

                if(!fixSpot){
                     vec2 param = transLevelToParam(ctrlLevel);
                     bgColor = calculateBlurValue(param.x, param.y);
//                     highp vec4 camColor = texture2D(inputImageTexture, textureCoordinate);
//                     bgColor = camColor;
                }
            }
    }

//    highp vec4 camColor = texture2D(inputImageTexture, textureCoordinate);
//    bgColor = camColor;

    gl_FragColor = bgColor;
}