#extension GL_OES_EGL_image_external : require

uniform sampler2D s_texture;

precision highp float;
uniform sampler2D inputImageTexture;
uniform sampler2D inputImageTexture1;
uniform sampler2D inputImageTexture2;

varying highp vec2 textureCoordinate;

uniform float texelWidth;
uniform float texelHeight;
uniform float ctrlLevel;
uniform int extra;

const lowp float pi = 3.14159265;

vec2 displayTileSize = vec2(0.025, 0.025);
float numTiles = 1080.0;
int colorOn = 1;



vec4 calcBkgndColor(const float level)
{
    highp float maplevel = 40.0 + (level*60.0 / 100.0);
    highp float aspectRatio = texelHeight/texelWidth;
    highp float fractionalWidthOfPixel = maplevel / (max(texelWidth, texelHeight));
    highp vec2 sampleDivisor = vec2(fractionalWidthOfPixel, fractionalWidthOfPixel / aspectRatio);
    highp vec2 samplePos = textureCoordinate - mod(textureCoordinate, sampleDivisor) + 0.5 * sampleDivisor;
    return texture2D(inputImageTexture, samplePos );
}

void main()
{
    vec2 maskCoord = vec2(textureCoordinate.x, textureCoordinate.y);
    highp vec4 camColor = texture2D(s_texture, textureCoordinate);
    highp vec4 maskColor = texture2D(inputImageTexture1, maskCoord);
    float a = smoothstep(0.1, 0.9, maskColor.r);

    highp vec4 bgColor;
    bool isMask = (maskColor.r + maskColor.g + maskColor.b) >= 1.0;
    bool isEdge = a > 0.0 && a < 1.0;

    if(isEdge){
           //bgColor = calcBkgndColor((1.0 - maskColor.r)*ctrlLevel);
           //bgColor = camColor;
           bgColor = calcBkgndColor(ctrlLevel);
       }else{
         if(isMask){
            bgColor = camColor;
           }else{
            bgColor = calcBkgndColor(ctrlLevel);
       }
    }

    gl_FragColor = bgColor;
}