#extension GL_OES_EGL_image_external : require

uniform sampler2D s_texture;

precision highp float;
uniform sampler2D inputImageTexture;
uniform sampler2D inputImageTexture1;

varying highp vec2 textureCoordinate;

uniform int extra;
uniform highp float texelWidth;
uniform highp float texelHeight;
uniform highp float ctrlLevel;


const lowp float pi = 3.14159265;

 float transformLevel(float level){
    return  level / 25.0;
 }

 vec4 calculateMotionBlurValue(float level)
 {
      float aspectRation = texelHeight/texelWidth;
      vec2 directionalTexelStep = vec2(transformLevel(level)*aspectRation/texelWidth, 0);
      vec2 oneStepBackTextureCoordinate = textureCoordinate.xy - directionalTexelStep;
      vec2 twoStepsBackTextureCoordinate = textureCoordinate.xy - 2.0 * directionalTexelStep;
      vec2 threeStepsBackTextureCoordinate = textureCoordinate.xy - 3.0 * directionalTexelStep;
      vec2 fourStepsBackTextureCoordinate = textureCoordinate.xy - 4.0 * directionalTexelStep;
      vec2 oneStepForwardTextureCoordinate = textureCoordinate.xy + directionalTexelStep;
      vec2 twoStepsForwardTextureCoordinate = textureCoordinate.xy + 2.0 * directionalTexelStep;
      vec2 threeStepsForwardTextureCoordinate = textureCoordinate.xy + 3.0 * directionalTexelStep;
      vec2 fourStepsForwardTextureCoordinate = textureCoordinate.xy + 4.0 * directionalTexelStep;

     lowp vec4 fragmentColor = texture2D(inputImageTexture, textureCoordinate) * 0.18;
     fragmentColor += texture2D(inputImageTexture, oneStepBackTextureCoordinate) * 0.15;
     fragmentColor += texture2D(inputImageTexture, twoStepsBackTextureCoordinate) *  0.12;
     fragmentColor += texture2D(inputImageTexture, threeStepsBackTextureCoordinate) * 0.09;
     fragmentColor += texture2D(inputImageTexture, fourStepsBackTextureCoordinate) * 0.05;
     fragmentColor += texture2D(inputImageTexture, oneStepForwardTextureCoordinate) * 0.15;
     fragmentColor += texture2D(inputImageTexture, twoStepsForwardTextureCoordinate) *  0.12;
     fragmentColor += texture2D(inputImageTexture, threeStepsForwardTextureCoordinate) * 0.09;
     fragmentColor += texture2D(inputImageTexture, fourStepsForwardTextureCoordinate) * 0.05;
     return fragmentColor;
 }

void main()
{
    vec2 maskCoord = vec2(textureCoordinate.x, textureCoordinate.y);
    highp vec4 maskColor = texture2D(inputImageTexture1, maskCoord);
    float a = smoothstep(0.1, 0.9, maskColor.r);

    highp vec4 bgColor;
    bool isMask = (maskColor.r + maskColor.g + maskColor.b) >= 1.0;
    bool isEdge = a > 0.0 && a < 1.0;

    if(isEdge){
             bgColor = calculateMotionBlurValue((1.0 - maskColor.r)*ctrlLevel);
       }else{
         if(isMask){
               highp vec4 camColor = texture2D(s_texture, textureCoordinate);
               bgColor = camColor;
           }else{
               bgColor = calculateMotionBlurValue(ctrlLevel);
       }
    }

    gl_FragColor = bgColor;
}