#extension GL_OES_EGL_image_external : require

uniform sampler2D s_texture;

precision highp float;
uniform sampler2D inputImageTexture;
uniform sampler2D inputImageTexture1;
uniform sampler2D inputImageTexture2;

varying highp vec2 textureCoordinate;
uniform mediump float blurLevel;

uniform int horizontal;
uniform int blurSize;
uniform float texelWidthOffset;
uniform float texelHeightOffset;
uniform float texelWidth;
uniform float texelHeight;

const lowp float pi = 3.14159265;

vec4 calcBkgndColor(const float level)
{
    vec2  uv = textureCoordinate.xy;
    float imageWidthFactor = 1.0/texelWidth;
    float imageHeightFactor = 1.0/texelHeight;
    float pixel = 1.0f * level / 10.0;
    float dx = pixel * imageWidthFactor;
    float dy = pixel * imageHeightFactor;
    vec2 coord = vec2(dx * floor(uv.x / dx), dy * floor(uv.y / dy));
    vec3 tc = texture2D(inputImageTexture, coord).xyz;
    vec4 ret = vec4(tc, 1.0);
    return ret;
}

vec4 calculateBlurValue(const int kernel, const float level){
    float sigma = level;
    float numBlurPixelsPerSide = float(kernel / 2);
    vec2  blurMultiplyVec = horizontal > 0 ? vec2(1.0, 0.0) : vec2(0.0, 1.0);
    vec2 singleStepOffset = vec2(texelWidthOffset, texelHeightOffset);

    vec3 incrementalGaussian;
    incrementalGaussian.x = 1.0 / (sqrt(2.0 * pi) * sigma);
    incrementalGaussian.y = exp(-0.5 / (sigma * sigma));
    incrementalGaussian.z = incrementalGaussian.y * incrementalGaussian.y;

    vec4 avgValue = vec4(0.0, 0.0, 0.0, 0.0);
    float coefficientSum = 0.0;

    // Take the central sample first...
    avgValue += texture2D(inputImageTexture, textureCoordinate.st) * incrementalGaussian.x;
    coefficientSum += incrementalGaussian.x;
    incrementalGaussian.xy *= incrementalGaussian.yz;

     // Go through the remaining 8 vertical samples (4 on each side of the center)
    for (float i = 1.0; i <= numBlurPixelsPerSide; i++) {
        avgValue += texture2D(inputImageTexture, textureCoordinate.st - i * singleStepOffset *
                                      blurMultiplyVec) * incrementalGaussian.x;
        avgValue += texture2D(inputImageTexture, textureCoordinate.st + i * singleStepOffset *
                                      blurMultiplyVec) * incrementalGaussian.x;
        coefficientSum += 2.0 * incrementalGaussian.x;
        incrementalGaussian.xy *= incrementalGaussian.yz;
     }
     return  avgValue / coefficientSum;
}

void main()
{
    vec2 maskCoord = vec2(textureCoordinate.x, textureCoordinate.y);
    highp vec4 camColor = texture2D(s_texture, textureCoordinate);
    highp vec4 maskColor = texture2D(inputImageTexture1, maskCoord);
    float a = smoothstep(0.1, 0.9, maskColor.r);

    highp vec4 bgColor;
    bool isMask = (maskColor.r + maskColor.g + maskColor.b) >= 1.0;
    bool isEdge = a > 0.0 && a < 1.0;

    if(isEdge){
           //bgColor = calculateBlurValue(9, (1.0f - maskColor.r)*blurLevel);
           bgColor = calcBkgndColor((1.0 - maskColor.r)*50.0);
       }else{
         if(isMask){
            bgColor = camColor;
           }else{
            bgColor = calcBkgndColor(50.0f);
       }
    }

    gl_FragColor = bgColor;
}