#extension GL_OES_EGL_image_external : require

uniform sampler2D s_texture;

precision highp float;
uniform sampler2D inputImageTexture;
uniform sampler2D inputImageTexture1;

varying highp vec2 textureCoordinate;
uniform int extra;
uniform float texelWidth;
uniform float texelHeight;
uniform float ctrlLevel;

// some const, tweak for best look
const float sampleDist = 1.0;


const lowp float pi = 3.14159265;

vec2 transLevelToParam(const float level){
    vec2 ret = vec2(0.0, 0.0);
    if(level < 33.0){
        ret.x = 5.0;
        ret.y = level / 33.0 * 1.5 + 2.0;
    }else if(level >= 33.0 && level <= 66.0){
        ret.x = 7.0f;
        ret.y = (level - 33.0)/33.0 * 1.5 + 2.5;
    }else{
        ret.x = 9.0f;
        ret.y = (level - 66.0)/33.0 * 2.0 + 3.0;
    }
    return ret;
}


vec4 calculateRadialBlurValue(const float level){
    // some sample positions
      float sampleStrength = 1.0 + level/25.0;
      float samples[10] = float[10](-0.08,-0.05,-0.03,-0.02,-0.01,0.01,0.02,0.03,0.05,0.08);

       // 0.5,0.5 is the center of the screen
       // so substracting uv from it will result in
       // a vector pointing to the middle of the screen
       vec2 dir = 0.5 - textureCoordinate;

       // calculate the distance to the center of the screen
       float dist = sqrt(dir.x*dir.x + dir.y*dir.y);

       // normalize the direction (reuse the distance)
       dir /= dist;

       // this is the original colour of this fragment
       // using only this would result in a nonblurred version
       vec4 color = texture2D(inputImageTexture,textureCoordinate);

       vec4 sum = color;

       // take 10 additional blur samples in the direction towards
       // the center of the screen
       for (int i = 0; i < 10; i++)
       {
         sum += texture2D( inputImageTexture, textureCoordinate + dir * samples[i] * sampleDist );
       }

       // we have taken eleven samples
       sum *= 1.0/11.0;

       // weighten the blur effect with the distance to the
       // center of the screen ( further out is blurred more)
       float t = dist * sampleStrength;
       t = clamp( t ,0.0,1.0); //0 <= t <= 1

       //Blend the original color with the averaged pixels
       return mix( color, sum, t );
 }

 vec4 calculateGassianBlurValue(const float kernel, const float level){
     float sigma = level;
     float numBlurPixelsPerSide = kernel / 2.0;
     int   horizontal = extra;
     vec2  blurMultiplyVec = horizontal > 0 ? vec2(1.0, 0.0) : vec2(0.0, 1.0);
     float offsetx = horizontal > 0 ? float(2.5f/texelWidth) : float(0.0);
     float offsety = horizontal > 0 ? float(0.0) : 2.5f/texelHeight;
     vec2  singleStepOffset = vec2(offsetx, offsety);

     vec3 incrementalGaussian;
     incrementalGaussian.x = 1.0 / (sqrt(2.0 * pi) * sigma);
     incrementalGaussian.y = exp(-0.5 / (sigma * sigma));
     incrementalGaussian.z = incrementalGaussian.y * incrementalGaussian.y;

     vec4 avgValue = vec4(0.0, 0.0, 0.0, 0.0);
     float coefficientSum = 0.0;

     // Take the central sample first...
     avgValue += texture2D(inputImageTexture, textureCoordinate.st) * incrementalGaussian.x;
     coefficientSum += incrementalGaussian.x;
     incrementalGaussian.xy *= incrementalGaussian.yz;

      // Go through the remaining 8 vertical samples (4 on each side of the center)
     for (float i = 1.0; i <= numBlurPixelsPerSide; i++) {
         avgValue += texture2D(inputImageTexture, textureCoordinate.st - i * singleStepOffset *
                                       blurMultiplyVec) * incrementalGaussian.x;
         avgValue += texture2D(inputImageTexture, textureCoordinate.st + i * singleStepOffset *
                                       blurMultiplyVec) * incrementalGaussian.x;
         coefficientSum += 2.0 * incrementalGaussian.x;
         incrementalGaussian.xy *= incrementalGaussian.yz;
      }
      return  avgValue / coefficientSum;
 }

void main()
{
    vec2 maskCoord = vec2(textureCoordinate.x, textureCoordinate.y);
    highp vec4 maskColor = texture2D(inputImageTexture1, maskCoord);
    float a = smoothstep(0.1, 0.9, maskColor.r);

    highp vec4 bgColor;
    bool isMask = (maskColor.r + maskColor.g + maskColor.b) >= 1.0;
    bool isEdge = a > 0.0 && a < 1.0;

    if(isEdge){
           vec2 param = transLevelToParam(ctrlLevel);
           bgColor = calculateGassianBlurValue(param.x, (1.0 - maskColor.r)*param.y);
       }else{
         if(isMask){
               highp vec4 camColor = texture2D(s_texture, textureCoordinate);
               bgColor = camColor;
           }else{
               bgColor = calculateRadialBlurValue(ctrlLevel);
       }
    }

    gl_FragColor = bgColor;
}